@@ -24,7 +24,7 @@ import macholib.dyld
 import macholib.MachO
 import macholib.MachOStandalone
 import pkg_resources
-from macholib.util import flipwritable, is_platform_file
+from macholib.util import flipwritable
 from modulegraph import modulegraph, zipio
 from modulegraph.find_modules import find_modules, find_needed_modules, parse_mf_results
 from modulegraph.modulegraph import Package, Script, SourceModule
@@ -32,6 +32,7 @@ from modulegraph.util import imp_find_module
 from setuptools import Command
 
 from py2app import recipes
+from py2app._pkg_meta import IGNORED_DISTINFO, scan_for_metadata
 from py2app.apptemplate.setup import main as script_executable
 from py2app.create_appbundle import create_appbundle
 from py2app.create_pluginbundle import create_pluginbundle
@@ -105,7 +106,6 @@ def loader_paths(sourcefn, destfn):
             yield os.path.join(sourcedir, relpath), os.path.join(destdir, relpath)
 
 
-
 def rewrite_tkinter_load_commands(tkinter_path):
     print("rewrite_tk", tkinter_path)
     m = macholib.MachO.MachO(tkinter_path)
@@ -226,7 +226,6 @@ class PythonStandalone(macholib.MachOStandalone.MachOStandalone):
             )
             self.ext_map[fn] = os.path.dirname(e.filename)
 
-
     def update_node(self, m):
         if isinstance(m, macholib.MachO.MachO):
             if m.filename in self.ext_map:
@@ -359,9 +358,9 @@ def installation_info(version=None):
         version = sys.version
 
     if is_system():
-        return version[:3] + " (FORCED: Using vendor Python)"
+        return ".".join(version.split(".")[:2]) + " (FORCED: Using vendor Python)"
     else:
-        return version[:3]
+        return ".".join(version.split(".")[:2])
 
 
 class py2app(Command):
@@ -612,12 +611,15 @@ class py2app(Command):
         self.no_report_missing_conditional_import = False
         self.redirect_stdout_to_asl = False
         self._python_app = None
+        self.use_old_sdk = False
         self.expected_missing_imports = None
 
     def finalize_options(self):
         if self.prefer_ppc:
-            print("WARNING: Option --prefer-ppc is deprecated an will be removed "
-                  "in a future version. Use --arch instead")
+            print(
+                "WARNING: Option --prefer-ppc is deprecated an will be removed "
+                "in a future version. Use --arch instead"
+            )
 
         if sys_base_prefix != sys.prefix:
             self._python_app = os.path.join(sys_base_prefix, "Resources", "Python.app")
@@ -823,7 +825,7 @@ class py2app(Command):
             prefix = sys.prefix
         if version is None:
             version = sys.version
-        version = version[:3]
+        version = ".".join(version.split(".")[:2])
         info = None
         if sys_base_prefix != sys.prefix:
             prefix = sys_base_prefix
@@ -861,7 +863,7 @@ class py2app(Command):
             dylib = info["name"]
             runtime = os.path.join(info["location"], info["name"])
         else:
-            dylib = "libpython%s.dylib" % (sys.version[:3],)
+            dylib = "libpython%d.%d.dylib" % (sys.version_info[:2])
             runtime = os.path.join(prefix, "lib", dylib)
 
         return dylib, runtime
@@ -1067,7 +1069,9 @@ class py2app(Command):
                 elif fn.endswith(".pyw"):
                     fn = fn[:-4]
 
-                src_fn = script_executable(arch=self.arch, secondary=True)
+                src_fn = script_executable(
+                    arch=self.arch, secondary=True, use_old_sdk=self.use_old_sdk
+                )
                 tgt_fn = os.path.join(
                     target.appdir, "Contents", "MacOS", os.path.basename(fn)
                 )
@@ -1137,6 +1141,9 @@ class py2app(Command):
                 if rval.get("frameworks"):
                     self.frameworks.extend(rval["frameworks"])
 
+                if rval.get("use_old_sdk"):
+                    self.use_old_sdk = True
+
                 for fn in newbootstraps:
                     if isinstance(fn, basestring):
                         mf.run_script(fn)
@@ -1465,11 +1472,13 @@ class py2app(Command):
         bdist_base = self.bdist_base
         if self.semi_standalone:
             self.bdist_dir = os.path.join(
-                bdist_base, "python%s-semi_standalone" % (sys.version[:3],), "app"
+                bdist_base,
+                "python%d.%d-semi_standalone" % (sys.version_info[:2]),
+                "app",
             )
         else:
             self.bdist_dir = os.path.join(
-                bdist_base, "python%s-standalone" % (sys.version[:3],), "app"
+                bdist_base, "python%d.%d-standalone" % (sys.version_info[:2]), "app"
             )
 
         if os.path.exists(self.bdist_dir):
@@ -1502,6 +1511,9 @@ class py2app(Command):
         pkgexts = []
         copyexts = []
         extmap = {}
+        included_metadata = set()
+
+        metadata_infos = scan_for_metadata(sys.path)
 
         def packagefilter(mod, pkgdirs=pkgdirs):
             fn = os.path.realpath(getattr(mod, "filename", None))
@@ -1512,6 +1524,35 @@ class py2app(Command):
                     return None
             return fn
 
+        for mod in py_files + extensions:
+            fn = os.path.realpath(getattr(mod, "filename", None))
+            if fn is None:
+                return None
+
+            dist_info_path = metadata_infos.get(fn, None)
+            if dist_info_path is None and (fn.endswith(".pyc") or fn.endswith(".pyo")):
+                dist_info_path = metadata_infos.get(fn[:-1], None)
+            if dist_info_path is not None:
+                included_metadata.add(dist_info_path)
+
+        def files_in_dir(toplevel):
+            for dirname, _, fns in os.walk(toplevel):
+                for fn in fns:
+                    yield os.path.realpath(os.path.join(dirname, fn))
+
+        for pd in pkgdirs:
+            # Ensure that packages included through the packages option
+            # get their metadata included as well, even if the python
+            # package contains files from multiple package distributions
+            for fn in files_in_dir(pd):
+                dist_info_path = metadata_infos.get(fn, None)
+                if dist_info_path is None and (
+                    fn.endswith(".pyc") or fn.endswith(".pyo")
+                ):
+                    dist_info_path = metadata_infos.get(fn[:-1], None)
+                if dist_info_path is not None:
+                    included_metadata.add(dist_info_path)
+
         if pkgdirs:
             py_files = list(filter(packagefilter, py_files))
         for ext in extensions:
@@ -1541,6 +1582,21 @@ class py2app(Command):
                 continue
             self.copy_package_data(item, self.collect_dir)
 
+        # copy package metadata
+        for pkg_info_path in included_metadata:
+            base = os.path.join(self.collect_dir, os.path.basename(pkg_info_path))
+            os.mkdir(base)
+
+            for fn in os.listdir(pkg_info_path):
+                if fn in IGNORED_DISTINFO:
+                    continue
+                src = os.path.join(pkg_info_path, fn)
+                dst = os.path.join(base, fn)
+                if os.path.isdir(src):
+                    self.copy_tree(src, dst, preserve_symlinks=False)
+                else:
+                    self.copy_file(src, dst)
+
         self.lib_files = []
         self.app_files = []
 
@@ -1665,7 +1721,11 @@ class py2app(Command):
                     platfiles = self.strip_dsym(platfiles)
                     self.strip_files(platfiles)
 
-                arch = self.arch if self.arch is not None else get_platform().split("-")[-1]
+                arch = (
+                    self.arch
+                    if self.arch is not None
+                    else get_platform().split("-")[-1]
+                )
 
                 if arch in ("universal2", "arm64"):
                     codesign_adhoc(target.appdir)
@@ -1736,7 +1796,7 @@ class py2app(Command):
                     copy_file(pth, os.path.join(target_dir, fname))
 
     def strip_dsym(self, platfiles):
-        """ Remove .dSYM directories in the bundled application """
+        """Remove .dSYM directories in the bundled application"""
 
         #
         # .dSYM directories are contain detached debugging information and
@@ -2128,6 +2188,7 @@ class py2app(Command):
             extension=self.extension,
             arch=self.arch,
             redirect_stdout=self.redirect_stdout_to_asl,
+            use_old_sdk=self.use_old_sdk,
         )
         appdir = fsencoding(appdir)
         resdir = os.path.join(appdir, "Contents", "Resources")
@@ -2160,8 +2221,10 @@ class py2app(Command):
         make_symlink(pyExecutable, execdst)
 
         # make PYTHONHOME
-        pyhome = os.path.join(resdir, "lib", "python" + sys.version[:3])
-        realhome = os.path.join(sys.prefix, "lib", "python" + sys.version[:3])
+        pyhome = os.path.join(resdir, "lib", "python%d.%d" % (sys.version_info[:2]))
+        realhome = os.path.join(
+            sys.prefix, "lib", "python%d.%d" % (sys.version_info[:2])
+        )
         makedirs(pyhome)
         if self.optimize:
             make_symlink("../../site.pyo", os.path.join(pyhome, "site.pyo"))
@@ -2243,11 +2306,12 @@ class py2app(Command):
             next = []
             for item in todo:
                 for s, d in loader_paths(*item):
-                    if os.path.exists(d): continue
+                    if os.path.exists(d):
+                        continue
                     next.append((s, d))
                     if not self.dry_run:
-                       if not os.path.exists(os.path.dirname(d)):
-                          os.makedirs(os.path.dirname(d))
+                        if not os.path.exists(os.path.dirname(d)):
+                            os.makedirs(os.path.dirname(d))
                     copy_file(s, d, dry_run=self.dry_run)
             todo = next
 
@@ -2266,7 +2330,9 @@ class py2app(Command):
             elif fn.endswith(".pyw"):
                 fn = fn[:-4]
 
-            src_fn = script_executable(arch=self.arch, secondary=False)
+            src_fn = script_executable(
+                arch=self.arch, secondary=False, use_old_sdk=self.use_old_sdk
+            )
             tgt_fn = os.path.join(
                 self.appdir, "Contents", "MacOS", os.path.basename(fn)
             )
@@ -2330,10 +2396,12 @@ class py2app(Command):
         pydir = os.path.join(resdir, "lib", "python%s.%s" % (sys.version_info[:2]))
 
         if sys.version_info[0] == 2 or self.semi_standalone:
-            arcdir = os.path.join(resdir, "lib", "python" + sys.version[:3])
+            arcdir = os.path.join(resdir, "lib", "python%d.%d" % (sys.version_info[:2]))
         else:
             arcdir = os.path.join(resdir, "lib")
-        realhome = os.path.join(sys.prefix, "lib", "python" + sys.version[:3])
+        realhome = os.path.join(
+            sys.prefix, "lib", "python%d.%d" % (sys.version_info[:2])
+        )
         self.mkpath(pydir)
 
         # The site.py file needs to be a two locations
