@@ -18,7 +18,10 @@ sys.path.append(_parent + "/site-packages.zip")
 # add the uncompressed site-packages to the path to compensate for that.
 sys.path.append(_parent + "/site-packages")
 
+ENABLE_USER_SITE = False
+
 USER_SITE = None
+USER_BASE = None
 
 
 def _import_os():
@@ -127,6 +130,57 @@ def addpackage(sitedir, name):
         _dirs_in_sys_path = None
 
 
+def _get_path(userbase):
+    version = sys.version_info
+
+    if sys.platform == "darwin" and getattr(sys, "_framework", None):
+        return "%s/lib/python/site-packages" % (userbase,)
+
+    return "%s/lib/python%d.%d/site-packages" % (userbase, version[0], version[1])
+
+
+def _getuserbase():
+    env_base = os.environ.get("PYTHONUSERBASE", None)
+    if env_base:
+        return env_base
+
+    def joinuser(*args):
+        return os.path.expanduser(os.path.join(*args))
+
+    if getattr(sys, "_framework", None):
+        return joinuser("~", "Library", sys._framework, "%d.%d" % sys.version_info[:2])
+
+    return joinuser("~", ".local")
+
+
+def getuserbase():
+    """Returns the `user base` directory path.
+
+    The `user base` directory can be used to store data. If the global
+    variable ``USER_BASE`` is not initialized yet, this function will also set
+    it.
+    """
+    global USER_BASE
+    if USER_BASE is None:
+        USER_BASE = _getuserbase()
+    return USER_BASE
+
+
+def getusersitepackages():
+    """Returns the user-specific site-packages directory path.
+
+    If the global variable ``USER_SITE`` is not initialized yet, this
+    function will also set it.
+    """
+    global USER_SITE
+    userbase = getuserbase()  # this will also set USER_BASE
+
+    if USER_SITE is None:
+        USER_SITE = _get_path(userbase)
+
+    return USER_SITE
+
+
 #
 # Run custom site specific code, if available.
 #
@@ -143,6 +197,8 @@ except ImportError:
 if hasattr(sys, "setdefaultencoding"):
     del sys.setdefaultencoding
 
-import builtins
-import _sitebuiltins
+import builtins  # noqa: E402
+
+import _sitebuiltins  # noqa: E402
+
 builtins.help = _sitebuiltins._Helper()
